==> libgtop-2.14.7.tar.bz2: libgtop-2.14.7/sysdeps/linux/procargs.c <==
/* $Id: procargs.c 2422 2005-12-12 09:38:15Z jamesh $ */

/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop.h>
#include <glibtop/error.h>
#include <glibtop/procargs.h>

static const unsigned long _glibtop_sysdeps_proc_args =
(1L << GLIBTOP_PROC_ARGS_SIZE);

/* Init function. */

void
glibtop_init_proc_args_s (glibtop *server)
{
	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
}

/* Provides detailed information about a process. */

char *
glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
			 pid_t pid, unsigned max_len)
{
	char filename[48]; /* magiv */

	char *args;
	gsize length;
	GError *error = NULL;

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_ARGS, 0);

	memset (buf, 0, sizeof (glibtop_proc_args));

	sprintf (filename, "/proc/%d/cmdline", pid);

	if(!g_file_get_contents(filename, &args, &length, &error)) {
		g_error_free(error);
		buf->size = 0;
		return NULL;
	}

	if(max_len && max_len < length) {
		args = g_realloc(args, max_len);
		args[max_len - 1] = '\0';
		length = max_len;
	}

	buf->size = length;
	buf->flags = _glibtop_sysdeps_proc_args;

	return args;
}

==> libgtop-2.14.9.tar.bz2: libgtop-2.14.9/sysdeps/linux/procargs.c <==
/* Copyright (C) 1998-99 Martin Baulig
   This file is part of LibGTop 1.0.

   Contributed by Martin Baulig <martin@home-of-linux.org>, April 1998.

   LibGTop is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License,
   or (at your option) any later version.

   LibGTop is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
   for more details.

   You should have received a copy of the GNU General Public License
   along with LibGTop; see the file COPYING. If not, write to the
   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#include <config.h>
#include <glibtop.h>
#include <glibtop/error.h>
#include <glibtop/procargs.h>

static const unsigned long _glibtop_sysdeps_proc_args =
(1L << GLIBTOP_PROC_ARGS_SIZE);

/* Init function. */

void
_glibtop_init_proc_args_s (glibtop *server)
{
	server->sysdeps.proc_args = _glibtop_sysdeps_proc_args;
}

/* Provides detailed information about a process. */

char *
glibtop_get_proc_args_s (glibtop *server, glibtop_proc_args *buf,
			 pid_t pid, unsigned max_len)
{
	char filename[48]; /* magiv */

	char *args;
	gsize length;
	GError *error = NULL;

	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_ARGS, 0);

	memset (buf, 0, sizeof (glibtop_proc_args));

	sprintf (filename, "/proc/%d/cmdline", pid);

	if(!g_file_get_contents(filename, &args, &length, &error)) {
		g_error_free(error);
		buf->size = 0;
		return NULL;
	}

	if(max_len && max_len < length) {
		args = g_realloc(args, max_len);
		args[max_len - 1] = '\0';
		length = max_len;
	}

	buf->size = length;
	buf->flags = _glibtop_sysdeps_proc_args;

	return args;
}
